import {
  select,
  csv,
  scaleLinear,
  axisLeft,
  axisBottom,
  extent,
  scaleTime,
  area,
  curveBasis
} from 'd3';

const titleText = 'Temperature in San Francisco';
const xAxisLabelText = 'Time';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const xValue = d => d.timestamp;
  const yValue = d => d.temperature;
  const circleRadious = 1.8;
  const margin = { top: 56, right: 40, bottom: 88, left: 115 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
  .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .ticks(6)                       
    .tickSize(-innerHeight)
  	.tickPadding(15);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
    .tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.select('.domain').remove();
  yAxisG.append('text')
    .attr('class', 'axis-label')
    .attr('y', -70)
    .attr('x', -innerHeight / 2)
    .attr('fill', 'black')
    .attr('transform', `rotate(-90)`)
  	.attr('text-anchor', 'middle')
    .text('Temperature');
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 75)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabelText);
  
  const areaGenerator = area()
  	.x(d => xScale(xValue(d)))
  	.y0(innerHeight)
    .y1(d => yScale(yValue(d)))
  	.curve(curveBasis);
  
  g.append('path')
  	.attr('class', 'line-path')
  	.attr('d', areaGenerator(data))
  
  g.append('text')
      .attr('class', 'title')
      .attr('y', -15)
      .text(titleText);
};

csv('https://vizhub.com/curran/datasets/temperature-in-san-francisco.csv').then(data => {
  data.forEach(d => {
    d.temperature = +d.temperature;
    d.timestamp = new Date(d.timestamp);
  });
  render(data);
});